/*
	Once you have loaded the plugin, run the following mel commands to select your tool.

			global string $g_circle_context;
			$g_circle_context = `CircleSelectContext`;
			setToolTo $g_circle_context;

	to delete the tool, use

			deleteUI -tc $g_circle_context;

*/

#include "CircleSelectTool.h"

#include <maya/MFnPlugin.h>

// required to link the libraries
#ifdef WIN32
	#pragma comment(lib,"Foundation.lib")
	#pragma comment(lib,"OpenMaya.lib")
	#pragma comment(lib,"OpenMayaFx.lib")
	#pragma comment(lib,"OpenMayaUi.lib")
	#pragma comment(lib,"Image.lib")
	#pragma comment(lib,"OpenMayaAnim.lib")
	#pragma comment(lib,"OpenGl32.lib")
	#pragma comment(lib,"glu32.lib")
#endif

// under WIN32 we have to 'export' these functions so that they are visible
// inside the dll. If maya can't see the functions, it can't load the plugin!
#ifdef WIN32
	#define EXPORT __declspec(dllexport)
#else
	#define EXPORT
#endif


EXPORT MStatus initializePlugin( MObject obj )
{
	MStatus		status;
	MFnPlugin	fnPlugin( obj, "Rob Bateman", "1.0", "Any");

	// register the tool command
	status = fnPlugin.registerContextCommand( "CircleSelectContext",
										    CircleSelectToolCommand::creator );

	// check error
	if (!status) {
		status.perror("registerContextCommand");
		return status;
	}

	// set the mel scripts to be run when the plugin is loaded / unloaded
	status = fnPlugin.registerUI("CircleSelectToolCreateUI", "CircleSelectToolDeleteUI");

	// check error
	if (!status) {
		status.perror("registerUIScripts");
		return status;
	}

	return status;
}

EXPORT MStatus uninitializePlugin( MObject obj )
{
	MStatus		status;
	MFnPlugin	fnPlugin( obj );

	// deregister the tool command
	status = fnPlugin.deregisterContextCommand( "CircleSelectContext" );

	// check error
	if (!status) {
		status.perror("deregisterContextCommand");
		return status;
	}

	return status;
}
